from import_export import fields, resources
from import_export.widgets import ForeignKeyWidget, ManyToManyWidget

from ..references.models import (
    Commune,
    Etiquette,
    FormeJuridique,
    StatutStructure,
)
from ..resources_mixin import ChoicesWidget, FkExplicitError, UserMixin
from .fields_choices import STATUT_BIO
from .models import Personne, Structure


class StructureResource(UserMixin, FkExplicitError, resources.ModelResource):
    class Meta:
        model = Structure
        clean_model_instances = True
        skip_unchanged = True
        import_id_fields = ('id',)
        fields = (
            'id',
            'designation',
            'statutbio',  # Integer
            'siret',
            'f_juridique',  # FK ref.FormeJuridique
            'statut',  # FK ref.StatutStructure
            'cat_act_agriculteur',  # boolean
            'cat_act_collecteur',  # boolean
            'cat_act_transformateur',  # boolean
            'cat_act_commerce_gros',  # boolean
            'cat_act_commerce_detail',  # boolean
            'cat_act_autre',
            'commentaire',
            'etiquettes',  # M2M ref.Etiquette
            'visibilite',
            'description_activite',
            'description_activite_map',  # description fiche
            'description_web',  # description liste
            'description_photo',  # ImageField
            'adresse',
            'code_postal',
            'ville',
            'commune__nom',
            'commune_insee',  # FK ref.Commune
            'non_courrier',
            'geolocalisation',
            'tel_fixe',
            'tel_mobile',
            'fax',
            'courriel',
            'pas_de_courriel',
            'site_web',
            'sau_eau',  # Decimal
            'sau_eau_bio',  # Decimal
            'origine_contact',
            'annee_contact',  # Integer
            'mois_contact',  # Integer
        )
        export_order = fields

    statutbio = fields.Field(
        column_name='statutbio',
        attribute='statutbio',
        widget=ChoicesWidget(choices=STATUT_BIO),
    )

    f_juridique = fields.Field(
        column_name='f_juridique',
        attribute='f_juridique',
        widget=ForeignKeyWidget(FormeJuridique, field='designation'),
    )
    statut = fields.Field(
        column_name='statut',
        attribute='statut',
        widget=ForeignKeyWidget(StatutStructure, field='designation'),
    )
    commune_insee = fields.Field(
        column_name='commune_insee',
        attribute='commune',
        widget=ForeignKeyWidget(Commune, field='code_insee'),
    )
    etiquettes = fields.Field(
        column_name='etiquettes',
        attribute='etiquettes',
        widget=ManyToManyWidget(Etiquette, field='designation', separator='|'),
    )


class PersonneResource(UserMixin, FkExplicitError, resources.ModelResource):
    class Meta:
        model = Personne
        clean_model_instance = True
        skip_unchanged = True
        import_id_fields = ('id',)
        fields = (
            'id',
            'structure',  # FK
            'civilite',
            'nom',
            'prenom',
            'date_naissance',
            'date_installation',
            'fonction',
            'adresse',
            'commune__nom',
            'commune_insee',  # FK
            'code_postal',
            'ville',
            'courrier_structure',
            'tel_fixe',
            'tel_mobile',
            'fax',
            'courriel',
            'pas_de_courriel',
            'reseaux_engagements',
        )
        export_order = fields

    structure = fields.Field(
        column_name='structure',
        attribute='structure',
        widget=ForeignKeyWidget(Structure, field='designation'),
    )

    commune_insee = fields.Field(
        column_name='commune_insee',
        attribute='commune',
        widget=ForeignKeyWidget(Commune, field='code_insee'),
    )
