# -*- coding: utf-8 -*-
from django.contrib import admin

import gaby.references.models as ref_models

from ..admin_mixin import ImportExportMixin
from .resources import (
    EtiquetteResource,
    FormeJuridiqueResource,
    StatutStructureResource,
)


class PraAdmin(admin.ModelAdmin):
    "petite region agricole"
    list_display = ('nom', 'code', 'grande_region', 'departement')
    list_filter = ('departement',)


class ArrondissementAdmin(admin.ModelAdmin):
    list_display = ('nom', 'departement')
    list_filter = ('departement',)


class CommuneAdmin(admin.ModelAdmin):
    list_display = (
        'nom',
        'code_insee',
        'code_postal',
        'arrondissement',
        'petite_region',
        'territoire',
        'agence_eau',
        'enjeu_eau',
    )
    list_filter = ('agence_eau', 'enjeu_eau', 'territoire', 'petite_region')
    search_fields = ('nom',)


class DesignationObjetAdmin(admin.ModelAdmin):
    "Personnalisation de l'admin des tables basées sur DesignationObjet."
    search_fields = ('designation',)


class EtiquetteAdmin(ImportExportMixin, DesignationObjetAdmin):
    "Personnalisation de l'admin du modèle Etiquette."
    list_display = ('designation', 'description')
    search_fields = ('designation',)
    resource_class = EtiquetteResource


class NomObjetAdmin(admin.ModelAdmin):
    "Personnalisation de l'admin des tables basées sur NomObjet."
    pass


class CultureAdmin(admin.ModelAdmin):
    "Personnalisation de l'admin du modèle Culture."
    list_display = ('designation', 'categorie_cul', 'indice_ordre', 'enabled')
    list_editable = ('categorie_cul', 'indice_ordre', 'enabled')
    search_fields = ('categorie_cul__designation', 'designation')


class FormeJuridiqueAdmin(ImportExportMixin, DesignationObjetAdmin):
    resource_class = FormeJuridiqueResource


class StatutStructureAdmin(ImportExportMixin, DesignationObjetAdmin):
    resource_class = StatutStructureResource


def register_models(site):
    "Enregistrement des modèles dans un AdminSite passé en paramètre."
    site.register(ref_models.Etiquette, EtiquetteAdmin)
    site.register(ref_models.Territoire)
    site.register(ref_models.PublicCible)
    site.register(ref_models.PetiteRegionAgricole, PraAdmin)
    site.register(ref_models.Arrondissement, ArrondissementAdmin)
    site.register(ref_models.Commune, CommuneAdmin)

    #    site.register(ref_models.CategorieStructure, DesignationObjetAdmin)
    site.register(ref_models.StatutCommercialisation, DesignationObjetAdmin)
    site.register(ref_models.Laiterie, NomObjetAdmin)
    site.register(ref_models.OrganismeDeCertification, NomObjetAdmin)
    site.register(ref_models.StatutStructure, StatutStructureAdmin)
    site.register(ref_models.TypeService, DesignationObjetAdmin)
    site.register(ref_models.Culture, CultureAdmin)
    site.register(ref_models.CategorieCulture)
    site.register(ref_models.ClientCulture, DesignationObjetAdmin)
    site.register(ref_models.Abattoir, NomObjetAdmin)
    site.register(ref_models.AcheteurOeufs, DesignationObjetAdmin)
    site.register(ref_models.Formation, DesignationObjetAdmin)
    site.register(ref_models.TypeFormation, DesignationObjetAdmin)
    site.register(ref_models.FormeJuridique, FormeJuridiqueAdmin)
    site.register(ref_models.FinanceProg, DesignationObjetAdmin)


# register_models(admin.site)
# EOF
