from django.core.exceptions import (
    MultipleObjectsReturned,
    ObjectDoesNotExist,
    ValidationError,
)
from django.utils.encoding import force_text

from import_export.widgets import Widget


class UserMixin:
    def after_import_instance(self, instance, new, **kwargs):
        if instance.utilisateur_derniere_modification_id is None:
            user = kwargs.get('user')
            user = user and user.id
            instance.utilisateur_derniere_modification_id = user
        super().after_import_instance(instance, new, **kwargs)


class FkExplicitError:
    def import_obj(self, obj, data, dry_run):
        "inject error flag in instance"
        obj._error_flag = False
        try:
            super().import_obj(obj, data, dry_run)
        except ValidationError as err:
            obj._error_flag = True
            raise (err)

    def skip_row(self, instance, original):
        "does not skip row if there is an error flag"
        if instance._error_flag:
            return False
        return super().skip_row(instance, original)

    def import_field(self, field, obj, data, is_m2m=False):
        "convert DoesNotExist or MultipleObjectsReturn into ValueError"
        try:
            super().import_field(field, obj, data, is_m2m)
        except (ObjectDoesNotExist, MultipleObjectsReturned) as err:
            if isinstance(err, ObjectDoesNotExist):
                raise ValueError('non trouvé(e)')
            else:
                raise ValueError('non unique')


class ChoicesWidget(Widget):
    def __init__(self, choices=None, *args, **kwargs):
        """
        choices est une liste de liste comme l'argument "choices"
        des CharField
        cast est un callable appele pour changer le type si
        besoin
        """
        self.export_map = {} if choices is None else dict(choices)
        self.import_map = {y: x for x, y in self.export_map.items()}
        super().__init__(*args, **kwargs)

    def clean(self, value, row=None, *args, **kwargs):
        "import"
        return self.import_map.get(str(value).strip(), None)

    def render(self, value, obj=None):
        "export"
        return force_text(self.export_map.get(value, ""))
